#
# spec file for package python-zlib-ng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

Name:           python-zlib-ng%{psuffix}
Version:        0.4.0
Release:        1.1
License:        Python-2.0
Summary:        Faster zlib and gzip compatible compression and decompression
Group:          Development/Languages/Python
URL:            https://github.com/pycompression/python-zlib-ng
Source0:        https://files.pythonhosted.org/packages/source/z/zlib-ng/zlib-ng-%{version}.tar.gz
Source1:        https://github.com/pycompression/python-zlib-ng/raw/v%{version}/tests/data/concatenated.fastq.gz
Source2:        https://github.com/pycompression/python-zlib-ng/raw/v%{version}/tests/data/seeds.txt
Source3:        https://github.com/pycompression/python-zlib-ng/raw/v%{version}/tests/data/test.fastq.bgzip.gz
Source4:        https://github.com/pycompression/python-zlib-ng/raw/v%{version}/tests/data/test.fastq.gz
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  zlib-ng-devel
Provides:       python-zlib_ng = %{version}-%{release}
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module zlib-ng = %{version}}
%endif
%python_subpackages

%description
Faster zlib and gzip compatible compression and decompression by providing Python bindings for the zlib-ng library.

This package provides Python bindings for the zlib-ng library.

%prep
%setup -q -n zlib-ng-%{version}
mkdir tests/data
cp %{SOURCE1} %{SOURCE2} %{SOURCE3}  %{SOURCE4} tests/data/

%build
%if !%{with test}
export PYTHON_ZLIB_NG_LINK_DYNAMIC=1
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%if %{with test}
%check
%pytest_arch
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/zlib_ng
%{python_sitearch}/zlib_ng-%{version}.dist-info
%endif

%changelog
* Tue Feb  6 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.4.0
  * Add a gzip_ng_threaded module that contains the
    gzip_ng_threaded.open function. This allows using multithreaded
    compression as well as escaping the GIL.
  * The internal gzip_ng._GzipReader has been rewritten in C. As a
    result the overhead of decompressing files has significantly
    been reduced.
  * The gzip_ng._GzipReader in C is now used in gzip_ng.decompress.
    The _GzipReader also can read from objects that support the
    buffer protocol. This has reduced overhead significantly.
  * Fix some unclosed buffer errors in the gzip_ng CLI.
- Version 0.3.0
  * Source distributions on Linux now default to building with
    configure and make as it is faster and has less dependencies
    than CMake.
  * Python 3.12 support was added. Python 3.7 support was dropped
    as it is end of life.
  * Update embedded zlib-ng version to 2.1.5. This comes with some
    speed improvements and changes with regards to the compression
    levels. Also several bugs were fixed. For full details checkout
    the zlib-ng 2.1.2 release notes as well as those for the bugfix
    releases 2.1.3, 2.1.4 and 2.1.5.
- Fix BuildRequirements. This one never used poetry.
- Enable tests in multibuild: some tests call python3.X -m zlib_ng
  without respecting the PYTHONPATH from %%pytest_arch.
- Link to system library
* Wed Dec  6 2023 Adrian Schröter <adrian@suse.de>
- initial package of version 0.2.0
